@@ -1,4 +1,4 @@
-#1/usr/bin/env sh
+#!/usr/bin/env sh
 
 set -e
 
@@ -9,6 +9,10 @@ sed -i "" -E '1a\
   namespace = "default"
 ' example.nomad
 
+# default cpu sometimes too high for local
+sed -i "" -E "s/cpu    = 500/cpu    = 50/g" example.nomad
+sed -i "" -E "s/memory = 256/memory = 32/g" example.nomad
+
 run_job() {
     sed -i "" -E "s/job \".*\"/job \"${1:-example}\"/" example.nomad
     sed -i "" -E "s/namespace = \".*\"/namespace = \"${2:-default}\"/" example.nomad
